import { LitElement, TemplateResult } from 'lit';
declare type LabelPosition = 'left' | 'right' | 'top' | 'bottom';
declare const UUIBooleanInputBaseElement_base: (new (...args: any[]) => import("../mixins/LabelMixin").LabelMixinInterface) & typeof LitElement;
/**
 * Base class wrapping native input type="checkbox". Extend if you need to make a custom boolean input. Change the role of the input by passing a 'checkbox' || 'switch' to the super() when extending this class. Default is checkbox. Extending this class will make your element formAssociated, meaning it can participate in the native form element.
 * @extends LabelMixin
 * @fires UUIBooleanInputEvent#change on change
 * @abstract
 */
export declare abstract class UUIBooleanInputBaseElement extends UUIBooleanInputBaseElement_base {
    static styles: import("lit").CSSResult[];
    /**
     * This is a static class field indicating that the element is can be used inside a native form and participate in its events. It may require a polyfill, check support here https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/attachInternals.  Read more about form controls here https://web.dev/more-capable-form-controls/
     * @type {boolean}
     */
    static readonly formAssociated = true;
    readonly _internals: any;
    private inputRole;
    constructor(inputRole?: 'checkbox' | 'switch');
    protected _input: HTMLInputElement;
    private _value;
    /**
     * This is a value property of the uui-checkbox or the uui-toggle component. The default value of this property is 'on'. It reflects the behaviour of the native input type="checkbox" element and its value attribute.
     * @type {string}
     * @attr
     * @default on
     */
    get value(): string;
    set value(newVal: string);
    /**
     * This is the name property of the uui-checkbox or the uui-toggle component. It reflects the behaviour of the native input type="checkbox" element and its name attribute.
     * @type {string}
     * @attr
     * @default ''
     */
    name: string;
    /**
     * Specifies the label position of the checkbox or the toggle
     * @type {'left' | 'right' | 'top' | 'bottom'}
     * @attr label-position
     * @default right
     */
    labelPosition: LabelPosition;
    /**
     * Set to true to hide the labeling provided by the component.
     * @type {boolean}
     * @attr hide-label
     * @default false
     */
    hideLabel: boolean;
    /**
     * Set to true if the component should have an error state. Property is reflected to the corresponding attribute.
     * @type {boolean}
     * @attr error
     * @default false
     */
    error: boolean;
    private _checked;
    /**
     * Reflects the state of the element. True if checkbox or toggle is checked. Change this to switch the state programmatically.
     * @type {boolean}
     * @attr
     * @default false
     */
    get checked(): boolean;
    set checked(newVal: boolean);
    /**
     * Reflects the disabled state of the element. True if checkbox or toggle is disabled. Change this to switch the state programmatically.
     * @type {boolean}
     * @attr
     * @default false
     */
    disabled: boolean;
    private _onInputChange;
    /**
     * When extending UUIBooleanInputBase class you need to implement this abstract method. It should return a template of your input.
     * @returns {TemplateResult}
     * @abstract
     * @method
     */
    protected abstract renderCheckbox(): TemplateResult;
    render(): TemplateResult<1>;
}
export {};
